# chem-ant

Select materials to output molecules similar to the target molecule with MCTS Solver and Genetic Programming.
This is a part of [Chess-Ant](https://github.com/akuroiwa/chess-ant) project.

If you want to install this package on Python 3.12, please be sure to read the manual above beforehand.

Please install the required packages using the following commands:

```console
pip install git+https://github.com/Global-Chem/global-chem.git#subdirectory=global_chem
pip install git+https://github.com/Global-Chem/global-chem.git#subdirectory=global_chem_extensions
```
